@@ -4,6 +4,7 @@ use Mojo::Base 'Mojo::EventEmitter';
 use Carp 'croak';
 use Compress::Raw::Zlib qw(WANT_GZIP Z_STREAM_END);
 use Mojo::Headers;
+use Mojo::Util 'deprecated';
 use Scalar::Util 'looks_like_number';
 
 has [qw(auto_decompress auto_relax expect_close relaxed skip_body)];
@@ -24,6 +25,7 @@ sub boundary {
   (shift->headers->content_type // '') =~ $BOUNDARY_RE ? $1 // $2 : undef;
 }
 
+# DEPRECATED in Clinking Beer Mugs!
 sub build_body    { shift->_build('get_body_chunk') }
 sub build_headers { shift->_build('get_header_chunk') }
 
@@ -53,19 +55,11 @@ sub get_body_chunk {
   croak 'Method "get_body_chunk" not implemented by subclass';
 }
 
-sub get_header_chunk {
-  my ($self, $offset) = @_;
+sub get_header_chunk { substr shift->_headers->{header_buffer}, shift, 131072 }
 
-  unless (defined $self->{header_buffer}) {
-    my $headers = $self->headers->to_string;
-    $self->{header_buffer}
-      = $headers ? "$headers\x0d\x0a\x0d\x0a" : "\x0d\x0a";
-  }
+sub header_size { length shift->_headers->{header_buffer} }
 
-  return substr $self->{header_buffer}, $offset, 131072;
-}
-
-sub header_size { length shift->build_headers }
+sub headers_contain { index(shift->_headers->{header_buffer}, shift) >= 0 }
 
 sub is_chunked { !!shift->headers->transfer_encoding }
 
@@ -175,18 +169,16 @@ sub write_chunk {
   return $self;
 }
 
+# DEPRECATED in Clinking Beer Mugs!
 sub _build {
+  deprecated 'Mojo::Content::build_body and Mojo::Content::build_headers'
+    . ' are DEPRECATED';
   my ($self, $method) = @_;
 
   my ($buffer, $offset) = ('', 0);
   while (1) {
-
-    # No chunk yet, try again
     next unless defined(my $chunk = $self->$method($offset));
-
-    # End of part
     last unless my $len = length $chunk;
-
     $offset += $len;
     $buffer .= $chunk;
   }
@@ -228,6 +220,14 @@ sub _decompress {
     if length($self->{post_buffer} // '') > $self->max_buffer_size;
 }
 
+sub _headers {
+  my $self = shift;
+  return $self if defined $self->{header_buffer};
+  my $headers = $self->headers->to_string;
+  $self->{header_buffer} = $headers ? "$headers\x0d\x0a\x0d\x0a" : "\x0d\x0a";
+  return $self;
+}
+
 sub _parse_chunked {
   my $self = shift;
 
@@ -458,18 +458,6 @@ Content size in bytes. Meant to be overloaded in a subclass.
 
 Extract multipart boundary from C<Content-Type> header.
 
-=head2 build_body
-
-  my $str = $content->build_body;
-
-Render whole body.
-
-=head2 build_headers
-
-  my $str = $content->build_headers;
-
-Render all headers.
-
 =head2 charset
 
   my $charset = $content->charset;
@@ -499,13 +487,21 @@ overloaded in a subclass.
 
   my $bytes = $content->get_header_chunk(13);
 
-Get a chunk of the headers starting from a specific position.
+Get a chunk of the headers starting from a specific position. Note that this
+method finalizes the content.
 
 =head2 header_size
 
   my $size = $content->header_size;
 
-Size of headers in bytes.
+Size of headers in bytes. Note that this method finalizes the content.
+
+=head2 headers_contain
+
+  my $bool = $content->headers_contain('foo bar baz');
+
+Check if headers contain a specific string. Note that this method finalizes the
+content.
 
 =head2 is_chunked
 
