@@ -183,7 +183,9 @@ sub parse {
   return $self->emit('progress')->content->is_finished ? $self->finish : $self;
 }
 
-sub start_line_size { length shift->build_start_line }
+sub start_line_size {
+  croak 'Method "start_line_size" not implemented by subclass';
+}
 
 sub text {
   my $self    = shift;
@@ -302,6 +304,7 @@ Mojo::Message - HTTP message base class
   sub cookies              {...}
   sub extract_start_line   {...}
   sub get_start_line_chunk {...}
+  sub start_line_size      {...}
 
 =head1 DESCRIPTION
 
@@ -438,19 +441,19 @@ Content size in bytes.
 
   my $bytes = $msg->build_body;
 
-Render whole body.
+Render whole body with L</"get_body_chunk">.
 
 =head2 build_headers
 
   my $bytes = $msg->build_headers;
 
-Render all headers.
+Render all headers with L</"get_header_chunk">.
 
 =head2 build_start_line
 
   my $bytes = $msg->build_start_line;
 
-Render start-line.
+Render start-line with L</"get_start_line_chunk">.
 
 =head2 cookie
 
@@ -547,13 +550,16 @@ Make sure message has all required headers.
 
   my $bytes = $msg->get_body_chunk($offset);
 
-Get a chunk of body data starting from a specific position.
+Get a chunk of body data starting from a specific position. Note that it might
+not be possible to get the same chunk twice if content was generated
+dynamically.
 
 =head2 get_header_chunk
 
   my $bytes = $msg->get_header_chunk($offset);
 
-Get a chunk of header data, starting from a specific position.
+Get a chunk of header data, starting from a specific position. Note that this
+method finalizes the message.
 
 =head2 get_start_line_chunk
 
@@ -566,7 +572,7 @@ overloaded in a subclass.
 
   my $size = $msg->header_size;
 
-Size of headers in bytes.
+Size of headers in bytes. Note that this method finalizes the message.
 
 =head2 headers
 
@@ -617,7 +623,7 @@ Parse message chunk.
 
   my $size = $msg->start_line_size;
 
-Size of the start-line in bytes.
+Size of the start-line in bytes. Meant to be overloaded in a subclass.
 
 =head2 text
 
@@ -630,7 +636,9 @@ L</"default_charset">.
 
   my $str = $msg->to_string;
 
-Render whole message.
+Render whole message. Note that this method finalizes the message, and that it
+might not be possible to render the same message twice if content was generated
+dynamically.
 
 =head2 upload
 
