@@ -16,7 +16,7 @@ has match =>
 
 # Reserved stash values
 my %RESERVED = map { $_ => 1 } (
-  qw(action app cb controller data extends format handler json layout),
+  qw(action app cb controller data extends format handler inline json layout),
   qw(namespace path status template text variant)
 );
 
@@ -869,9 +869,9 @@ Non-persistent data storage and exchange for the current request, application
 wide default values can be set with L<Mojolicious/"defaults">. Some stash
 values have a special meaning and are reserved, the full list is currently
 C<action>, C<app>, C<cb>, C<controller>, C<data>, C<extends>, C<format>,
-C<handler>, C<json>, C<layout>, C<namespace>, C<path>, C<status>, C<template>,
-C<text> and C<variant>. Note that all stash values with a C<mojo.*> prefix are
-reserved for internal use.
+C<handler>, C<inline>, C<json>, C<layout>, C<namespace>, C<path>, C<status>,
+C<template>, C<text> and C<variant>. Note that all stash values with a
+C<mojo.*> prefix are reserved for internal use.
 
   # Remove value
   my $foo = delete $c->stash->{foo};
